summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xwiki/redesign.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/wiki/redesign.py b/wiki/redesign.py
index 0c4f79a..bea9180 100755
--- a/wiki/redesign.py
+++ b/wiki/redesign.py
@@ -659,9 +659,9 @@ def mb_stgen(mb):
# Aggressive, assistant and fast mobs yield more exp
# Slow monsters yield less exp, because they're easier to kill on any playstyle
if magr:
- fx-=0.1
+ fx-=0.09
else:
- fx-=0.05
+ fx-=0.04
if mass:
fx-=0.08
if mv < 200:
@@ -674,9 +674,10 @@ def mb_stgen(mb):
lxp=exp[lv-1]/(lv**fx)
else:
lxp=3 # 3~5 is fine
# Boss are BOSS. It gives roughly 0.1% from lvlup xp.
else:
lxp=exp[lv]/1000
+ hxp=exp[lv]/10
# Force HP to be higher
@@ -674,9 +674,10 @@ def mb_stgen(mb):
else:
lxp=3 # 3~5 is fine
- # Boss are BOSS. It gives roughly 0.1% from lvlup xp.
+ # Boss are BOSS. It gives roughly 0.1% ~ 10.0% from lvlup xp.
else:
lxp=exp[lv]/1000